@@ -4,7 +4,7 @@ fn main() {
     let cars = vec![
         vec!["Make", "Model", "Color", "Year", "Price", ],
         vec!["Ford", "Pinto", "Green", "1978", "$750.00", ],
-        vec!["Toyota", "Tacoma", "Red", "2006", "15,475.23", ],
+        vec!["Toyota", "Tacoma", "Red", "2006", "$15,475.23", ],
         vec!["Lamborghini", "Diablo", "Yellow", "2001", "$238,459.99", ],
     ];
 
